@@ -34,7 +34,9 @@ use UNIVERSAL qw( isa can );
 use attributes qw(get reftype);
 use warnings;
 use ETL::Pequel::Type;
-
+use vars qw($VERSION $BUILD);
+$VERSION = "2.4-3";
+$BUILD = 'Tuesday November  1 08:45:13 GMT 2005';
 # ----------------------------------------------------------------------------------------------------
 {
 	package ETL::Pequel::Docgen;
