@@ -34,7 +34,9 @@ use strict;
 use attributes qw(get reftype);
 use warnings;
 use constant DEBUG => 0;
-
+use vars qw($VERSION $BUILD);
+$VERSION = "2.4-3";
+$BUILD = 'Tuesday November  1 08:45:13 GMT 2005';
 # ----------------------------------------------------------------------------------------------------
 {
 	package ETL::Pequel::Param;
